admit_row_insert_batches

Function admit_row_insert_batches 

pub async fn admit_row_insert_batches(
    batches: &mut [(QueryContextRef, RowInsertRequests)],
) -> Result<()>
Admits all database totals before dispatching any batch of a finite request. Each batch keeps its own protocol options and target database.